var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s)
        if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
            t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { h } from "@stencil/core";
import { DataTestIdsEnum } from "../../../../../constants/dataTestIds.enum";
import { formatAddress } from "../../../../../utils/utils";
import state from "../../signTransactionsModalStore";
export class SignTransaction {
    getSignButtonProps() {
        const { currentIndex, nextUnsignedTxIndex } = state.commonData;
        if (currentIndex === nextUnsignedTxIndex) {
            return {
                signText: 'Sign',
                disabled: state.isWaitingForSignature,
                'data-testid': DataTestIdsEnum.signTransactionBtn,
                onClick: state.onSign
            };
        }
        return {
            signText: 'Next',
            disabled: false,
            'data-testid': DataTestIdsEnum.signNextTransactionBtn,
            onClick: state.onNext
        };
    }
    getBackButtonProps() {
        const { transactionsCount, currentIndex } = state.commonData;
        const isMultipleTransactions = transactionsCount > 1;
        if (!isMultipleTransactions) {
            return {};
        }
        if (currentIndex === 0) {
            return {
                'data-testid': DataTestIdsEnum.signCancelBtn,
                backButtonText: 'Cancel',
                onClick: state.onCancel
            };
        }
        return {
            'data-testid': DataTestIdsEnum.signBackBtn,
            backButtonText: 'Back',
            onClick: state.onPrev,
            disabled: state.isWaitingForSignature
        };
    }
    getHighlightedData() {
        const { data, highlight } = state.commonData;
        if (!highlight || !data) {
            return data;
        }
        const parts = data.split(highlight);
        return (h("span", null, parts.map((part, index) => (h("span", null, h("span", { class: "data-content" }, part), index < parts.length - 1 && (h("span", { class: "highlight" }, highlight)))))));
    }
    render() {
        const { receiver, egldLabel, feeInFiatLimit, feeLimit, scCall } = state.commonData;
        const _a = this.getSignButtonProps(), { signText } = _a, signButtonProps = __rest(_a, ["signText"]);
        const _b = this.getBackButtonProps(), { backButtonText } = _b, backButtonProps = __rest(_b, ["backButtonText"]);
        const highlightedData = this.getHighlightedData();
        return (h("div", { key: '574ed1e9a1642b7bc3226498a35335e498bdc9d4', class: "transaction-container" }, this.header, h("div", { key: 'af59f69bcdd8aaaa30fb5cc36582fbffda60d3bb', class: "receiver-container" }, h("p", { key: '9cea15da3b5ae363d12a8f73167885923534940c' }, "To"), h("p", { key: '56f5531b96a485994f92e52b9fc99920af345dd2' }, formatAddress(receiver, 40))), h("div", { key: 'f6f3243b480b7f665bc80ee88ae771814659c0c2', class: "fee-container" }, h("p", { key: '2c7cbf01e53e21052414c69478a994184c64206e' }, "Transaction fee"), feeLimit && (h("p", { key: '6d3ec84478a29932c20a75978c45179bf8ae71e1' }, h("span", { key: '2f1b16c585e3c4c892a359fc22a14cf358675c83' }, feeLimit), "\u00A0", h("span", { key: 'b81536ff972120283fa18f06d81cfaa0b3ed163b' }, egldLabel))), h("p", { key: 'ba15b1bda597e83dd1ac59decbe89a36806e3b7a' }, "\u2248", feeInFiatLimit)), scCall && (h("div", { key: '472e00c12f90830b841f6c58d5437c9254fb6338', class: "data-container" }, h("p", { key: '50985529d37160bc6647ff21340dfe55a1b72a4b' }, "Smart Contract Call"), h("div", { key: '64cd71cf2d91dec4198beef1333e5f612b5e3913', class: "data-content-container" }, scCall))), h("div", { key: '777bc6db1d48305514009d1783b15e31704a57f9', class: "data-container" }, h("p", { key: 'bb4435622f4eae4d9f0088d62a5b2dfe7afdb077' }, "Data"), h("div", { key: '9178ac8da76f583bce5e8ede791ed2d0fd3e66a8', class: "data-content-container" }, highlightedData)), h("div", { key: '8ad6d00d28bad86bb944e057fe631d60617fdbc9', class: "sign-button-container" }, h("button", Object.assign({ key: '4c83b5583f47be1a0c8483a9c42c32c297c9875a', class: "sign-button" }, signButtonProps), signText), backButtonText && (h("button", Object.assign({ key: 'a59da4961f2ded131b112a7f4b537fe1a7ce03c2', class: "sign-back-button" }, backButtonProps), backButtonText)))));
    }
    static get is() { return "sign-transaction-component"; }
    static get originalStyleUrls() {
        return {
            "$": ["sign-transaction-component.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["sign-transaction-component.css"]
        };
    }
    static get properties() {
        return {
            "header": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "VNode",
                    "resolved": "VNode",
                    "references": {
                        "VNode": {
                            "location": "import",
                            "path": "@stencil/core",
                            "id": "node_modules::VNode"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false
            }
        };
    }
}
//# sourceMappingURL=sign-transaction-component.js.map
