import { r as registerInstance, h } from './index-755f1da5.js';
import { b as faCopy, c as faCheck, d as faCircleNotch, a as faTimes } from './index-b6ac87da.js';
import { c as classNames } from './index-097075ad.js';
import { D as DataTestIdsEnum } from './dataTestIds.enum-55de9911.js';
import { g as getIconHtmlFromIconDefinition } from './getIconHtmlFromIconDefinition-2377fd50.js';

const isWindowAvailable = () => typeof window != 'undefined' && typeof (window === null || window === void 0 ? void 0 : window.location) != 'undefined';

function fallbackCopyTextToClipboard(text) {
    let success = false;
    if (!document || !document.body) {
        console.error('Document or document.body is not available');
        return success;
    }
    const textArea = document.createElement('textarea');
    textArea.value = text;
    textArea.style.position = 'fixed';
    textArea.style.left = '-9999px';
    textArea.style.top = '0';
    document.body.appendChild(textArea);
    try {
        textArea.focus();
        textArea.setSelectionRange(0, textArea.value.length);
        success = document.execCommand('copy');
    }
    catch (err) {
        console.error('Fallback: Oops, unable to copy', err);
    }
    finally {
        document.body.removeChild(textArea);
    }
    return success;
}
async function copyToClipboard(text) {
    if (!isWindowAvailable()) {
        return false;
    }
    let success = false;
    if (!navigator.clipboard) {
        success = fallbackCopyTextToClipboard(text);
    }
    else {
        success = await navigator.clipboard.writeText(text).then(function done() {
            return true;
        }, function error(err) {
            console.error('Async: Could not copy text: ', err);
            return false;
        });
    }
    return success;
}

const copyButtonCss = ".copy-button{color:#6c757d}";
const CopyButtonStyle0 = copyButtonCss;

const CopyButton = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.isSuccess = false;
        this.handleClick = async (event) => {
            event.preventDefault();
            event.stopPropagation();
            const trimmedText = this.text ? this.text.trim() : this.text;
            const success = await copyToClipboard(trimmedText);
            this.isSuccess = success;
            if (success) {
                this.timeoutId = window.setTimeout(() => {
                    this.isSuccess = false;
                }, 1000);
            }
        };
    }
    disconnectedCallback() {
        // Clear the timeout if the component is unmounted
        if (this.timeoutId) {
            clearTimeout(this.timeoutId);
            this.timeoutId = undefined; // Reset the timeout ID
        }
    }
    render() {
        var _a, _b;
        const copyIcon = (_a = this.copyIcon) !== null && _a !== void 0 ? _a : faCopy;
        const successIcon = (_b = this.successIcon) !== null && _b !== void 0 ? _b : faCheck;
        return (h("a", { key: '6b0c10e58f3ffaac022fbdee8caf4768419ebf4b', href: "/#", class: classNames(this.class, 'copy-button'), onClick: this.handleClick }, h("fa-icon", { key: '84a69e772d8b67e8beadfe5f765247a2a2275977', icon: this.isSuccess ? successIcon : copyIcon })));
    }
};
CopyButton.style = CopyButtonStyle0;

const transactionToastDetailsBodyCss = ".transaction-container {\n  line-height: 1.5;\n  font-size: 0.875rem;\n  padding-right: 0.5rem;\n  display: flex;\n  align-items: center;\n  margin-bottom: 0.2rem;\n  justify-content: space-between;\n  --explorer-link-color: #6c757d;\n\n  .actions {\n    display: flex;\n    align-items: center;\n    gap: 0.75rem;\n  }\n\n  .icon {\n    svg {\n      font-size: 0.875rem;\n      color: #6c757d;\n      margin-right: 0.25rem;\n      width: 1rem;\n    }\n  }\n\n  .fa-spin {\n    svg {\n      animation: spin 2s linear infinite;\n    }\n  }\n\n  .trim {\n    width: 11rem;\n    white-space: nowrap;\n    margin-right: 1rem;\n  }\n}\n\n@keyframes spin {\n  0% {\n    transform: rotate(0deg);\n  }\n  100% {\n    transform: rotate(360deg);\n  }\n}";
const TransactionToastDetailsBodyStyle0 = transactionToastDetailsBodyCss;

const iconData = {
    pending: faCircleNotch,
    success: faCheck,
    fail: faTimes,
    invalid: faTimes,
};
const TransactionDetailsBody = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.transactionClass = 'transaction-container';
    }
    render() {
        const statusIcon = this.status ? iconData[this.status] : null;
        const iconHtml = statusIcon ? getIconHtmlFromIconDefinition(statusIcon) : null;
        return (h("div", { class: this.transactionClass, key: this.hash, "data-testid": DataTestIdsEnum.transactionDetailsToastBody }, iconHtml && (h("div", { key: 'fe622e50c903c13e6c6f6541e1c59eebbc3b80dd', innerHTML: iconHtml, class: classNames('icon', {
                'fa-spin': this.status === 'pending',
            }) })), h("span", { key: 'e44b648d4d7535b7f0ae1cb405692eb782189716', class: "trim" }, h("trim-text", { key: '0872baff9c25ca1ecf0a791570724de526a04914', text: this.hash })), h("div", { key: 'c76f37e1a26b19228125f7b1cb24b22b5bbc09dd', class: "actions" }, h("copy-button", { key: 'a9e856abd3806ef51681f189c327920565fa12fe', text: this.hash }), h("explorer-link", { key: '9daafb9380ae662aaa53aad9d1d1f594c09d1f96', link: this.link }))));
    }
};
TransactionDetailsBody.style = TransactionToastDetailsBodyStyle0;

export { CopyButton as copy_button, TransactionDetailsBody as transaction_toast_details_body };

//# sourceMappingURL=copy-button_2.entry.js.map