import { r as registerInstance, c as createEvent, h } from './index-755f1da5.js';
import { a as faTimes } from './index-b6ac87da.js';
import { g as getIconHtmlFromIconDefinition } from './getIconHtmlFromIconDefinition-2377fd50.js';
import { c as classNames } from './index-097075ad.js';
import { D as DataTestIdsEnum } from './dataTestIds.enum-55de9911.js';
import { g as getIconHtmlFromIconName } from './getIconHtmlFromIconName-e542130f.js';

const customToastCss = ".toast-wrapper{border-radius:0.25rem;box-shadow:0 0.25rem 0.75rem rgba(0, 0, 0, 0.1);margin-bottom:0.7rem;padding:0.5rem;background-color:#fff;position:relative}.icon-close{position:absolute;right:16px;top:16px;cursor:pointer;font-size:1.5rem;font-weight:700;line-height:1;color:#000;text-shadow:0 1px 0 #fff;opacity:0.5;padding:0;background-color:rgba(0, 0, 0, 0);border:0;display:flex;align-items:center;margin:0 0.5rem;width:12px}.toast-body{display:flex;align-items:center;flex:1;font-size:16px}";
const CustomToastStyle0 = customToastCss;

const CustomToast = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.handleDeleteToast = createEvent(this, "handleDeleteToast", 7);
    }
    render() {
        const customToast = (h("div", { key: 'c6d4f3996f3abba066440621657e94c113883c55', class: "toast-wrapper" }, h("button", { key: 'eaa2a40bf1e1bb1453c04043abfcce48e239a0bb', onClick: () => this.handleDeleteToast.emit(), type: "button", class: "icon-close", innerHTML: getIconHtmlFromIconDefinition(faTimes) }), h("div", { key: '94b12b0b7ebf46b01a1516d4cbd050e458a5e658', class: "toast-body", ref: container => this.initializeToast(container) })));
        return customToast;
    }
    initializeToast(container) {
        if (!container || container.hasChildNodes()) {
            return;
        }
        const customElement = this.toast.instantiateToastElement();
        if (!customElement) {
            return;
        }
        container.appendChild(customElement);
    }
};
CustomToast.style = CustomToastStyle0;

const simpleToastCss = ".content {\n  display: flex;\n  align-items: center;\n}\n\n.content-left {\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  flex-direction: column;\n  padding-left: 0.5rem;\n  padding-right: 0.75rem;\n\n  &.no-icon {\n    display: none;\n  }\n}\n\n.content-icon {\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  width: 3rem;\n  height: 3rem;\n  border-radius: 50%;\n\n  svg {\n    height: auto;\n    width: 20px;\n\n    path {\n      fill: white;\n    }\n  }\n}\n\n.icon-close {\n  position: absolute;\n  right: 16px;\n  top: 16px;\n  font-size: 1.5rem;\n  font-weight: 700;\n  line-height: 1;\n  color: #000;\n  text-shadow: 0 1px 0 #fff;\n  opacity: 0.5;\n  padding: 0;\n  background-color: rgba(0, 0, 0, 0);\n  border: 0;\n  display: flex;\n  align-items: center;\n  margin: 0 0.5rem;\n  width: 12px;\n}\n\n.content-right {\n  display: flex;\n  flex-direction: column;\n  justify-content: center;\n  width: 100%;\n}\n\n.content-heading {\n  display: flex;\n  justify-content: space-between;\n  align-items: center;\n  margin-bottom: 0.25rem;\n\n  h5 {\n    margin: 0;\n    margin-bottom: 0.5rem;\n    font-weight: 500;\n    line-height: 1.2;\n    font-size: 1.25rem;\n  }\n}\n\n.content-message {\n  margin-top: 0.25rem;\n  font-size: 1rem;\n  &.no-margin {\n    margin-top: 0rem;\n  }\n}\n\n.subtitle {\n  font-size: 0.9rem;\n  font-weight: 500;\n  color: #6c757d;\n}\n\n.success {\n  background-color: #5cb85c;\n}\n\n.warning {\n  background-color: #ffc107;\n}\n\n.danger {\n  background-color: #d9534f;\n}\n";
const SimpleToastStyle0 = simpleToastCss;

const SimpleToast = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.handleDeleteToast = createEvent(this, "handleDeleteToast", 7);
    }
    render() {
        const { icon, iconClassName, title, message, subtitle } = this.toast;
        let iconHtml = null;
        if (typeof icon === 'string') {
            iconHtml = getIconHtmlFromIconName(icon);
        }
        if (icon instanceof HTMLElement) {
            iconHtml = icon.outerHTML;
        }
        return (h("transaction-toast-wrapper", { key: '8aa7787a2fda2dced1816fdee7b5bb498aa3437f', wrapperId: `toast-${this.toast.toastId}` }, h("div", { key: '53cf68bccba8b11ae54fd5c447933feba3f1fcbc', class: "content", "data-testid": DataTestIdsEnum.transactionToastContent }, iconHtml && (h("div", { key: '96c6b191aea45d65f5c14d268143dd15608a3469', class: classNames('content-left', { 'no-icon': !iconHtml }) }, h("div", { key: 'a148c7ac022b83996169a88418c88b8daf298c0b', class: classNames('content-icon', iconClassName), innerHTML: iconHtml }))), h("div", { key: '318ac773a0a007d44c2b9753fc97ca85f047c09b', class: "content-right" }, title && (h("div", { key: 'dcefd481fd3cebfeb59a34e319f6b076facf5bab', class: "content-heading" }, h("h5", { key: '9fb1856817b7b4c4bc96e138eabbc83653b3f317', class: "content-heading-title", "data-testid": DataTestIdsEnum.transactionToastTitle }, title))), h("button", { key: '04c0381fdeba7ca6dd8764ec241a608782949a96', onClick: () => this.handleDeleteToast.emit(), type: "button", class: "icon-close", innerHTML: getIconHtmlFromIconDefinition(faTimes) }), subtitle && h("div", { key: '0f1e4b40a06e09da3e85b01c8a9db77036ebbe85', class: "subtitle" }, subtitle), message && h("div", { key: 'e9da5d4906130a5f42c6bec5fad8df432ad066f8', class: classNames('content-message', { 'no-margin': !title && !subtitle }) }, message)))));
    }
};
SimpleToast.style = SimpleToastStyle0;

export { CustomToast as custom_toast, SimpleToast as simple_toast };

//# sourceMappingURL=custom-toast_2.entry.js.map