import { r as registerInstance, h, a as getElement } from './index-755f1da5.js';
import { e as faArrowUpRightFromSquare } from './index-b6ac87da.js';
import { c as classNames } from './index-097075ad.js';
import { D as DataTestIdsEnum } from './dataTestIds.enum-55de9911.js';

const explorerLinkCss = ".explorer-link{text-decoration:none;color:var(--explorer-link-color, -webkit-link);}";
const ExplorerLinkStyle0 = explorerLinkCss;

const ExplorerLink = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.hasSlotContent = false;
    }
    componentWillLoad() {
        this.hasSlotContent = !!this.hostElement.querySelector('[slot="content"]');
    }
    render() {
        var _a, _b;
        return (h("a", { key: '0aeaf037a767276aaa3fc103488769a0d4be9807', "data-testid": this.dataTestId, href: this.link, target: "_blank", class: classNames(this.class, 'explorer-link'), rel: "noreferrer" }, this.hasSlotContent ? h("slot", { name: "content" }) : (_a = this.text) !== null && _a !== void 0 ? _a : h("fa-icon", { icon: (_b = this.icon) !== null && _b !== void 0 ? _b : faArrowUpRightFromSquare })));
    }
    get hostElement() { return getElement(this); }
};
ExplorerLink.style = ExplorerLinkStyle0;

const ELLIPSIS = '...';

const trimTextCss = ".trim {\n  display: flex;\n  max-width: 100%;\n  overflow: hidden;\n  position: relative;\n  white-space: nowrap;\n\n  &.overflow {\n    .ellipsis {\n      display: block;\n    }\n  }\n\n  .left {\n    flex-shrink: 1;\n    font-size: 1px;\n\n    overflow: hidden;\n    text-overflow: ellipsis;\n    text-align: left;\n  }\n\n  .right {\n    flex-shrink: 1;\n    font-size: 1px;\n\n    overflow: hidden;\n    text-overflow: ellipsis;\n    white-space: nowrap;\n    direction: rtl;\n    text-align: right;\n  }\n\n  .left span,\n  .right span {\n    font-size: 0.875rem;\n    pointer-events: none;\n    user-select: none;\n  }\n\n  .ellipsis {\n    flex-shrink: 0;\n    display: none;\n    pointer-events: none;\n    user-select: none;\n  }\n\n  /* IE fix */\n  @media all and (-ms-high-contrast: none), (-ms-high-contrast: active) {\n    .right {\n      text-overflow: clip;\n    }\n  }\n\n  /* SAFARI fix */\n  @supports (-webkit-hyphens: none) {\n    .right,\n    .left {\n      letter-spacing: -0.001em;\n    }\n    .right {\n      text-overflow: clip;\n    }\n  }\n\n  .hidden-text-ref {\n    position: absolute;\n    display: block;\n    color: transparent;\n  }\n\n  @media (max-width: 1199.98px) {\n    max-width: 26rem;\n  }\n\n  @media (max-width: 991.98px) {\n    max-width: 12rem;\n  }\n\n  @media (max-width: 768px) {\n    max-width: 8rem;\n  }\n}\n\n.trim-wrapper {\n  display: flex;\n  max-width: 100%;\n  overflow: hidden;\n}\n\na:hover > .trim span {\n  color: #007bff;\n\n  &.hidden-text-ref {\n    color: transparent;\n  }\n}\n\na > .trim span,\n.text-primary > .trim span {\n  color: #1b46c2;\n\n  &.hidden-text-ref {\n    color: transparent;\n  }\n}\n\n.table .trim {\n  max-width: 10rem;\n}\n\n.table .trim-only-sm .trim {\n  max-width: none;\n\n  @media (max-width: 768px) {\n    max-width: 13rem;\n  }\n}\n\n.trim-fs-sm .trim {\n  .left span,\n  .right span,\n  .ellipsis {\n    font-size: 0.875rem;\n  }\n}\n\n.table .trim-size-xl .trim {\n  @media (max-width: 768px) {\n    max-width: 13rem;\n  }\n}\n";
const TrimTextStyle0 = trimTextCss;

const TrimText = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.overflow = false;
        this.checkOverflow = () => {
            if (this.hiddenTextRef && this.trimRef) {
                const hiddenWidth = this.hiddenTextRef.offsetWidth;
                const containerWidth = this.trimRef.offsetWidth;
                // Batch state updates to minimize re-renders
                if (this.overflow !== hiddenWidth > containerWidth) {
                    this.overflow = hiddenWidth > containerWidth;
                }
            }
        };
    }
    componentDidLoad() {
        this.setupResizeObserver();
        // Initial check after DOM elements exist
        requestAnimationFrame(() => this.checkOverflow());
    }
    disconnectedCallback() {
        var _a;
        (_a = this.resizeObserver) === null || _a === void 0 ? void 0 : _a.disconnect();
    }
    setupResizeObserver() {
        this.resizeObserver = new ResizeObserver(() => {
            this.checkOverflow();
        });
        if (this.trimRef) {
            this.resizeObserver.observe(this.trimRef);
        }
    }
    render() {
        var _a;
        const trimmedText = this.getTrimmedText();
        return (h("span", { key: '267404f72568698cdd5c645c2f4481e3fa9b2786', ref: el => (this.trimRef = el), class: classNames('trim', this.class, { overflow: this.overflow }), "data-testid": (_a = this.dataTestId) !== null && _a !== void 0 ? _a : DataTestIdsEnum.trim }, h("span", { key: 'ea7ebfdcc880631b600d90000f5b041c784d851c', ref: el => (this.hiddenTextRef = el), class: "hidden-text-ref" }, this.text), this.overflow ? (h("div", { class: "trim-wrapper" }, h("span", { class: "left" }, h("span", null, trimmedText.left)), h("span", { class: "ellipsis" }, ELLIPSIS), h("span", { class: "right" }, h("span", null, trimmedText.right)))) : (h("span", null, this.text))));
    }
    getTrimmedText() {
        const middleIndex = Math.floor(this.text.length / 2);
        return {
            left: this.text.slice(0, middleIndex),
            right: this.text.slice(middleIndex),
        };
    }
    get el() { return getElement(this); }
};
TrimText.style = TrimTextStyle0;

export { ExplorerLink as explorer_link, TrimText as trim_text };

//# sourceMappingURL=explorer-link_2.entry.js.map