import { r as registerInstance, c as createEvent, h, F as Fragment } from './index-755f1da5.js';
import { a as faTimes } from './index-b6ac87da.js';
import { c as classNames } from './index-097075ad.js';
import { D as DataTestIdsEnum } from './dataTestIds.enum-55de9911.js';
import { g as getIconHtmlFromIconDefinition } from './getIconHtmlFromIconDefinition-2377fd50.js';
import { g as getIconHtmlFromIconName } from './getIconHtmlFromIconName-e542130f.js';

const transactionToastContentCss = ".content {\n  display: flex;\n  align-items: center;\n}\n.content-left {\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  flex-direction: column;\n  padding-left: 0.5rem;\n  padding-right: 0.75rem;\n}\n.success {\n  background-color: #5cb85c;\n}\n.warning {\n  background-color: #ffc107;\n}\n.danger {\n  background-color: #d9534f;\n}\n.content-icon {\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  width: 3rem;\n  height: 3rem;\n  border-radius: 50%;\n  svg {\n    height: auto;\n    width: 20px;\n\n    path {\n      fill: white;\n    }\n  }\n}\n\n.icon-close {\n  cursor: pointer;\n  float: right;\n  font-size: 1.5rem;\n  font-weight: 700;\n  line-height: 1;\n  color: #000;\n  text-shadow: 0 1px 0 #fff;\n  opacity: 0.5;\n  padding: 0;\n  background-color: rgba(0, 0, 0, 0);\n  border: 0;\n  display: flex;\n  align-items: center;\n  margin: 0 0.5rem;\n  width: 12px;\n}\n\n.content-right {\n  display: block;\n  overflow: hidden;\n  width: 100%;\n}\n\n.content-heading {\n  display: flex;\n  justify-content: space-between;\n  margin-bottom: 0.25rem;\n}\n\n.content-heading-title {\n  margin: 0;\n  margin-bottom: 0.5rem;\n  font-weight: 500;\n  line-height: 1.2;\n  font-size: 1.25rem;\n}\n";
const TransactionToastContentStyle0 = transactionToastContentCss;

const TransactionToastContent = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.deleteToast = createEvent(this, "deleteToast", 7);
    }
    render() {
        const { icon, iconClassName, title, hasCloseButton } = this.toastDataState;
        let iconHtml = null;
        if (typeof icon === 'string') {
            iconHtml = getIconHtmlFromIconName(icon);
        }
        if (icon instanceof HTMLElement) {
            iconHtml = icon.outerHTML;
        }
        return (h("div", { key: 'd3b3313c82a73b388fb588d7a2deac714978255a', class: "content", "data-testid": DataTestIdsEnum.transactionToastContent }, h("div", { key: '2487d56ab8a0a7a2a4fe6804a284e6e50be04b28', class: "content-left" }, h("div", { key: '6b0b39b99b107c60964a20fa5fd17a1ab1d31f50', class: classNames('content-icon', iconClassName), innerHTML: iconHtml })), h("div", { key: 'd1688f1de429b216df75969ef9ed8d76cf05eb7d', class: "content-right" }, h("div", { key: '0536bf04b8fa4462eeb1e358ffb8911bd1f3d4a0', class: "content-heading" }, h("h5", { key: 'f28e71d5324123b0f689a68f263417c1ae14e9f5', class: "content-heading-title", "data-testid": DataTestIdsEnum.transactionToastTitle }, title), hasCloseButton && h("button", { key: '84d2c0cad69584b12f46179f29678881e131d24e', onClick: () => this.deleteToast.emit(), type: "button", class: "icon-close", innerHTML: getIconHtmlFromIconDefinition(faTimes) })), h("div", { key: '02c25c18a320b3e2481b719a11962cff3f5086e5', class: "content-heading-title" }, h("transaction-toast-details", { key: '48e08b6476eae44e979710aba06a5a949d6486fa', transactions: this.transactions, processedTransactionsStatus: this.processedTransactionsStatus })))));
    }
};
TransactionToastContent.style = TransactionToastContentStyle0;

const transactionToastDetailsCss = ".status-title{font-size:0.875rem;margin:0.25rem 0 0.5rem;line-height:1.5}";
const TransactionToastDetailsStyle0 = transactionToastDetailsCss;

const TransactionDetails = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
    }
    render() {
        if (this.transactions == null) {
            return null;
        }
        return (h(Fragment, null, h("div", { class: "status-title" }, this.processedTransactionsStatus), this.transactions.map(({ hash, status, link }) => (h("transaction-toast-details-body", { transactionClass: this.transactionClass, hash: hash, status: status, link: link, key: hash })))));
    }
};
TransactionDetails.style = TransactionToastDetailsStyle0;

const transactionToastProgressCss = "@keyframes progressiveFixedWidthExpansion{from{width:min(var(--start-width, 0%), 80%)}to{width:80%}}@keyframes progressiveInfiniteWidthExpansion{from{width:min(var(--start-width, 0%), 100%)}to{width:100%}}@keyframes quickWidthExpansion{from{width:0%}to{width:100%}}.transaction-toast-progress{position:relative}.transaction-toast-bar-wrapper{transition:opacity 250ms ease-in;background-color:lightgray;position:absolute;pointer-events:none;left:0;top:0;opacity:25%;bottom:0;right:0;display:flex;overflow:hidden;border-radius:0.25rem;flex-direction:row-reverse}.transaction-toast-bar{height:100%;right:0;top:0;bottom:0}.transaction-toast-bar.fixed{width:min(var(--start-width, 0%), 50%);background-color:white;animation-name:progressiveFixedWidthExpansion;animation-duration:var(--animation-duration, 6s);animation-timing-function:cubic-bezier(0.5, 0.95, 0, 0.35);animation-fill-mode:forwards}.transaction-toast-bar.infinite{width:20%;display:flex;flex-direction:row-reverse}.transaction-toast-bar.infinite .transaction-toast-bar-line{width:0%;background-color:white;animation-name:progressiveInfiniteWidthExpansion;animation-duration:var(--animation-duration, 60s);animation-timing-function:cubic-bezier(0.1, 0.95, 0.25, 0.75);animation-fill-mode:forwards;animation-delay:var(--animation-delay, 6s);height:100%;position:relative}.transaction-toast-bar.infinite .transaction-toast-bar-line:before{position:absolute;background-color:white;content:'';width:calc(4px / 2);right:-1px;top:0;bottom:0}.transaction-toast-bar.fill{width:0%;position:absolute;background-color:white}.transaction-toast-bar.fill.animate{animation:quickWidthExpansion 250ms linear forwards}.transaction-toast-bar-content{z-index:1;position:relative}";
const TransactionToastProgressStyle0 = transactionToastProgressCss;

const DEFAULT_INFINITE_ANIMATION_DURATION = 30;
const ToastProgress = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.currentTimestamp = Date.now() / 1000;
        this.hasTimeElapsed = false;
        this.expectedTransactionDuration = 0;
        this.secondsPassedSinceStart = 0;
        this.shouldShowProgressBar = false;
        this.percentagePassedSinceStart = 0;
        this.shouldQuickFill = false;
        this.infiniteProgressDelay = 0;
        this.infinitePercentagePassedSinceStart = 0;
        this.infinitePercentageAnimationDuration = DEFAULT_INFINITE_ANIMATION_DURATION + (this.endTime - this.startTime) * 2;
    }
    componentWillLoad() {
        this.updateProgress();
    }
    handleTimeChange() {
        this.updateProgress();
    }
    updateProgress() {
        this.shouldShowProgressBar = Boolean(this.endTime) && Boolean(this.startTime);
        if (!this.shouldShowProgressBar) {
            this.shouldQuickFill = true;
            this.timeElapsedTimeoutReference = setTimeout(() => (this.hasTimeElapsed = true), 500);
            return;
        }
        this.currentTimestamp = Date.now() / 1000;
        this.expectedTransactionDuration = this.endTime - this.startTime;
        this.secondsPassedSinceStart = this.currentTimestamp - this.startTime;
        this.percentagePassedSinceStart = this.expectedTransactionDuration > 0 ? (this.secondsPassedSinceStart / this.expectedTransactionDuration) * 100 : 0;
        this.infiniteProgressDelay = Math.max(0, this.expectedTransactionDuration - this.secondsPassedSinceStart);
        this.infinitePercentagePassedSinceStart = (this.secondsPassedSinceStart / (this.expectedTransactionDuration + this.infinitePercentageAnimationDuration)) * 100;
    }
    disconnectedCallback() {
        if (this.timeElapsedTimeoutReference) {
            clearTimeout(this.timeElapsedTimeoutReference);
        }
    }
    render() {
        return (h(Fragment, { key: '6970bfa00742ef6225ad28edf602ca31b8da3589' }, h("div", { key: '1fe8aa772f2181cc58e5dc30ccbb740cdf5b3936', class: "transaction-toast-bar-wrapper", style: { opacity: this.hasTimeElapsed ? '0' : '1' } }, h("div", { key: '84c6762edbb8aaf34c5a6d9e5a53e4b4813fd4d0', class: "transaction-toast-bar fixed", style: {
                '--animation-duration': `${this.expectedTransactionDuration}s`,
                '--start-width': `${this.percentagePassedSinceStart}%`,
            } }), h("div", { key: '243e7cc02b7bee192fb3af8a1fe106d25a37fd40', class: "transaction-toast-bar infinite" }, h("div", { key: '03d25f4498f53e2ba7dc15e27ff540406edd102b', class: "transaction-toast-bar-line", style: {
                '--start-width': `${this.infinitePercentagePassedSinceStart}%`,
                '--animation-duration': `${this.infinitePercentageAnimationDuration}s`,
                '--animation-delay': `${this.infiniteProgressDelay}s`,
            } })), h("div", { key: '2d0c8a0f17a2723b28c1af4b573a88a877b11acb', class: classNames('transaction-toast-bar fill', {
                animate: this.shouldQuickFill,
            }) })), h("div", { key: '02f212a0e2c2d618b0455c24da8b81d3d0b7e711', class: "transaction-toast-bar-content" }, h("slot", { key: '2ecca9dad14525b2db4de8324daa08581ff876a7' }))));
    }
    static get watchers() { return {
        "startTime": ["handleTimeChange"],
        "endTime": ["handleTimeChange"]
    }; }
};
ToastProgress.style = TransactionToastProgressStyle0;

export { TransactionToastContent as transaction_toast_content, TransactionDetails as transaction_toast_details, ToastProgress as transaction_toast_progress };

//# sourceMappingURL=transaction-toast-content_3.entry.js.map